@@ -1221,7 +1221,7 @@ pressure_range_set(struct libinput_tablet_tool *tool, double min, double max)
 
 	tool->pressure.wanted_range.min = min;
 	tool->pressure.wanted_range.max = max;
-	tool->pressure.has_configured_range = true;
+	tool->pressure.has_configured_range = min != 0.0 || max != 1.0;
 
 	return LIBINPUT_CONFIG_STATUS_SUCCESS;
 }
@@ -1762,8 +1762,9 @@ detect_pressure_offset(struct tablet_dispatch *tablet,
 	}
 
 	evdev_log_info(device,
-		       "Pressure offset detected on tool %s (serial %#x).  "
+		       "Pressure offset of %d%% detected on tool %s (serial %#x).  "
 		       "See %s/tablet-support.html\n",
+		       (int)(pressure_offset_as_double(offset) * 100),
 		       tablet_tool_type_to_string(tool->type),
 		       tool->serial,
 		       HTTP_DOC_LINK);
@@ -2191,13 +2192,13 @@ update_pressure_range(struct tablet_dispatch *tablet,
 	threshold->threshold.upper = hi;
 	threshold->threshold.lower = lo;
 
-	if (threshold->has_offset)
-		set_pressure_offset(threshold, threshold->offset);
-
 	/* Disable any heuristics */
 	if (tool->pressure.has_configured_range) {
 		threshold->has_offset = true;
 		threshold->heuristic_state = PRESSURE_HEURISTIC_STATE_DONE;
+		threshold->offset = pressure_offset_from_double(0.0);
+	} else if (threshold->has_offset) {
+		set_pressure_offset(threshold, threshold->offset);
 	}
 }
 
